﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Xml;

namespace WpfAbfahrt
{
    /// <summary>
    /// Interaktionslogik für MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        #error Hier den von der DB erhaltenen Schlüssel eintragen.
        const string key = "??????????";

        public MainWindow()
        {
            InitializeComponent();

            textBoxBahnhof.TextChanged += textBoxBahnhof_TextChanged;
        }

        //http://data.deutschebahn.com/dataset/api-fahrplan
        //Datenlizenz: Creative Commons Attribution 4.0 International (CC BY 4.0)
        //by: Deutsche Bahn AG

        class Bahnhof
        {
            string id;
            public string Id { get { return id; } }
            string name;
            public string Name { get { return name; } }

            public Bahnhof(string id, string name)
            {
                this.id = id;
                this.name = name;
            }

            public override string ToString()
            {
                return Name;
            }
        }

        private void listBoxBahnhöfe_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if(listBoxBahnhöfe.SelectedItem == null)
            {
                listBoxAbfahrten.Items.Clear();
                return;
            }

            string id = ((Bahnhof)listBoxBahnhöfe.SelectedItem).Id;

            var w = new WebClient();
            w.Encoding = Encoding.UTF8;

            var zeit = DateTime.Now.ToString(@"\&\da\te=yyyy-MM-dd\&\ti\me=HH\%3amm");

            var s = "";
            try
            {
                s = w.DownloadString(
                "https://open-api.bahn.de/bin/rest.exe/departureBoard?authKey="
                + key + "&lang=de&id=" + id + zeit);
            }
            catch(Exception ex)
            {
                MessageBox.Show("Fehler! " + ex.Message);
            }
            var doc = new XmlDocument();
            doc.LoadXml(s);
            var knotenListe = doc.GetElementsByTagName("Departure");
            listBoxAbfahrten.Items.Clear();
            foreach (XmlNode k in knotenListe)
            {
                string direction = k.Attributes["direction"].Value;
                string time = k.Attributes["time"].Value;
                listBoxAbfahrten.Items.Add(time + " " + direction);
            }
        }

        private void textBoxBahnhof_TextChanged(object sender, TextChangedEventArgs e)
        {
            var w = new WebClient();
            w.Encoding = Encoding.UTF8;
            var urlEnc = WebUtility.UrlEncode(textBoxBahnhof.Text);
            listBoxBahnhöfe.Items.Clear();
            var s = "";
            try
            {
                //Thread.Sleep(500);

                s = w.DownloadString(
                    "https://open-api.bahn.de/bin/rest.exe/location.name?authKey="
                    + key + "&lang=de&input=" + urlEnc);
            }
            catch(Exception ex)
            {
                MessageBox.Show("Fehler! " + ex.Message);
                return;
            }
            var doc = new XmlDocument();
            doc.LoadXml(s);
            var knotenListe = doc.GetElementsByTagName("StopLocation");
            foreach (XmlNode k in knotenListe)
            {
                string id = k.Attributes["id"].Value;
                string name = k.Attributes["name"].Value;
                listBoxBahnhöfe.Items.Add(new Bahnhof(id, name));
            }
        }
    }
}
